class CountryCodes:
    '''
    This is just a helper to generate useful data files. It isn't directly used
    in these examples.
    '''
    
    def __init__(self):
        self.parse_codes_data()   
        
    def parse_codes_data(self):
        lines = open('iso3166-1-a2.txt', 'rb').read().split('\n')
        self.codes = dict([ a.split(' ', 1) for a in lines[:-1] ])

    def get_country_code_from_name(self, guess_name):
        best_score = 100
        best_code = None
        for code, name in self.codes.items():
            score = self.levenshtein(guess_name, name)
            if score < best_score:
                best_score = score
                best_code = code
        return best_code

    def levenshtein(self, a, b):
        "Calculates the Levenshtein distance between a and b."
        n, m = len(a), len(b)
        if n > m:
            # Make sure n <= m, to use O(min(n,m)) space
            a,b = b,a
            n,m = m,n
            
        current = range(n+1)
        for i in range(1,m+1):
            previous, current = current, [i]+[0]*n
            for j in range(1,n+1):
                add, delete = previous[j]+1, current[j-1]+1
                change = previous[j-1]
                if a[j-1] != b[i-1]:
                    change = change + 1
                current[j] = min(add, delete, change)
                
        return current[n]




#!/usr/bin/env python
# -*- coding: utf-8 -*-

import unittest
import sys
import os
import warnings
import urllib

ROOT = os.path.abspath(os.path.join(os.path.dirname(__file__), '..'))
sys.path.insert(0, ROOT)

from test.test_base import TestBase
import pygooglechart as gc


class TestDataTypes(TestBase):

    def test_simple_data(self):
        s = gc.SimpleData([range(0, 62), [0, 1, 60, 61]])
        self.assertEquals(repr(s),
            'chd=s:ABCDEFGHIJKLMNOPQRSTUVWXYZ'
            'abcdefghijklmnopqrstuvwxyz0123456789,AB89')

    def test_text_data(self):
        s = gc.TextData([[0, 1, 99.9]])
        self.assertEquals(repr(s), 'chd=t:0.0,1.0,99.9')

    def test_ext_data(self):
        s = gc.ExtendedData([[0, 1, 4095]])
        self.assertEquals(repr(s), 'chd=e:AAAB..')


class TestScaling(TestBase):

    def test_simple_scale(self):
        sv = gc.SimpleData.scale_value

        self.raise_warnings(False)  # We know some of these give warnings
        self.assertEquals(sv(-10, [0, 1]), 0)
        self.assertEquals(sv(0, [0, 1]), 0)
        self.assertEquals(sv(.5, [0, 1]), 31)
        self.assertEquals(sv(30, [0, 1]), 61)
        self.assertEquals(sv(2222, [0, 10000]), 14)

        # Test for warnings
        self.raise_warnings(True)
        self.assertRaises(UserWarning, sv, -10, [0, 1])
        self.assertRaises(UserWarning, sv, 30, [0, 1])

    def test_text_scale(self):
        sv = gc.TextData.scale_value

        self.raise_warnings(False)
        self.assertEquals(sv(-10, [0, 1]), 0)
        self.assertEquals(sv(0, [0, 1]), 0)
        self.assertEquals(sv(.5, [0, 1]), 50)
        self.assertEquals(sv(30, [0, 1]), 100)
        self.assertEquals(sv(2222, [0, 10000]), 22.22)

        self.raise_warnings(True)
        self.assertRaises(UserWarning, sv, -10, [0, 1])
        self.assertRaises(UserWarning, sv, 30, [0, 1])

    def test_ext_scale(self):
        sv = gc.ExtendedData.scale_value

        self.raise_warnings(False)
        self.assertEquals(sv(-10, [0, 1]), 0)
        self.assertEquals(sv(0, [0, 1]), 0)
        self.assertEquals(sv(.5, [0, 1]), 2048)
        self.assertEquals(sv(30, [0, 1]), 4095)
        self.assertEquals(sv(2222, [0, 10000]), 910)

        self.raise_warnings(True)
        self.assertRaises(UserWarning, sv, -10, [0, 1])
        self.assertRaises(UserWarning, sv, 30, [0, 1])


class TestTitleStyle(TestBase):

    def test_title_style(self):

        chart = gc.SimpleLineChart(300, 100)
        chart.set_title_style()
        self.assertEquals(chart.title_colour, None)
        self.assertEquals(chart.title_font_size, None)

        chart = gc.SimpleLineChart(300, 100)
        chart.set_title_style(font_size=30)
        self.assertEquals(chart.title_colour, '333333')
        self.assertEquals(chart.title_font_size, 30)

        chart = gc.SimpleLineChart(300, 100)
        chart.set_title_style(colour='123456')
        self.assertEquals(chart.title_colour, '123456')
        self.assertEquals(chart.title_font_size, 13.5)

        chart = gc.SimpleLineChart(300, 100)
        chart.set_title_style(font_size=100, colour='123456')
        self.assertEquals(chart.title_colour, '123456')
        self.assertEquals(chart.title_font_size, 100)


class TestLineChart(TestBase):

    def test_none_data(self):
        chart = gc.SimpleLineChart(300, 100)
        chart.add_data([1, 2, 3, None, 5])
        print chart.get_url()
        self.assertChartURL(chart.get_url(), \
            '?cht=lc&chs=300x100&chd=e:AAMzZm__zM')


class TestQRChart(TestBase):

    def assertQRImage(self, chart, text):
        try:
            import PyQrcodec
        except ImportError:
            print 'PyQrCodec not installed. Can not test QR code image'
            return

        chart.download(self.temp_image)
        status, string = PyQrcodec.decode(self.temp_image)
        self.assertTrue(status)
        self.assertEquals(text, string)

    def test_simple(self):
        text = 'Hello World'
        chart = gc.QRChart(100, 150)
        chart.add_data(text)
        self.assertChartURL(chart.get_url(), \
            '?cht=qr&chs=100x150&chl=Hello%20World')

    def test_encoding(self):
        chart = gc.QRChart(100, 100)
        chart.add_data('Hello World')
        self.assertChartURL(chart.get_url(), \
            '?cht=qr&chs=100x100&chl=Hello%20World')

    def test_no_data(self):
        chart = gc.QRChart(100, 100)
        self.assertRaises(gc.NoDataGivenException, chart.get_url)

    def test_validate_image(self):
        text = 'Hello World'
        chart = gc.QRChart(100, 100)
        chart.add_data(text)
        chart.set_ec('H', 0)  # PyQrcodec seems to only work on higher EC
        self.assertQRImage(chart, text)

    def test_validate_utf8(self):
        text = 'こんにちは世界'  # Hello world in Japanese UTF-8
        chart = gc.QRChart(100, 100)
        chart.add_data(text)
        chart.set_ec('H', 0)
        self.assertQRImage(chart, text)

class TestGrammar(TestBase):

    types = ('Venn', 'GroupedHorizontalBar', 'GoogleOMeter', 'Scatter',
        'StackedVerticalBar', 'Map', 'StackedHorizontalBar', 'SimpleLine',
        'SparkLine', 'GroupedVerticalBar', 'SplineRadar', 'XYLine', 'Radar',
        'QR')

    def test_chart_types(self):
        ret = gc.ChartGrammar.get_possible_chart_types()
        diff = set(ret).symmetric_difference(set(TestGrammar.types))
        self.assert_(not diff)

    def test_google_chart(self):
        g = {
            'type': 'GoogleOMeter',
            'w': 100,
            'h': 100,
            'auto_scale': True,
            'x_range': [ 0, 10 ],
            'data': [
                [ 1, 5, 10 ]
            ],
        }
        grammar = gc.ChartGrammar()
        chart = grammar.parse(g)
#        print chart.get_url()
#        chart.download('meh.png')


if __name__ == "__main__":
    unittest.main()




#!/usr/bin/env python
"""
Copyright Gerald Kaszuba 2008

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from glob import glob

examples = glob('*.py')
notexamples = ['settings.py', 'helper.py', 'all.py']

for example in examples:
    if example in notexamples:
        continue
    module = example[:-3]
    print module
    __import__(module).main()




#!/usr/bin/env python
# -*- coding: utf-8 -*-

import unittest
import sys
import os
import warnings
import urllib

ROOT = os.path.abspath(os.path.join(os.path.dirname(__file__), '..'))
sys.path.insert(0, ROOT)

import pygooglechart as gc


class TestBase(unittest.TestCase):

    def setUp(self):

        # All tests require warnings to be raised
        self.raise_warnings(True)

        self.temp_image = 'temp.png'

    def tearDown(self):
        if os.path.exists(self.temp_image):
            os.unlink(self.temp_image)

    def raise_warnings(self, rw):
        gc._reset_warnings()

        if rw:
            warnings.simplefilter('error')
        else:
            # Don't print out warnings if we're expecting them--so we can have
            # nicer looking tests! :)
            warnings.simplefilter('ignore')

    def assertChartURL(self, url, query):
        self.assertTrue(url.endswith(query))






#!/usr/bin/env python
# -*- coding: utf-8 -*-

import unittest
import sys
import os
import warnings
import urllib

ROOT = os.path.abspath(os.path.join(os.path.dirname(__file__), '..'))
sys.path.insert(0, ROOT)

from test.test_base import TestBase
import pygooglechart as gc


if __name__ == "__main__":
    unittest.main()




#!/usr/bin/env python
"""
Copyright Gerald Kaszuba 2008

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""

import os
import sys
import math

ROOT = os.path.dirname(os.path.abspath(__file__))
sys.path.insert(0, os.path.join(ROOT, '..'))

from pygooglechart import Chart
from pygooglechart import SimpleLineChart
from pygooglechart import XYLineChart
from pygooglechart import SparkLineChart
from pygooglechart import Axis

import settings
import helper

def simple_random():
    chart = SimpleLineChart(settings.width, settings.height, y_range=(0, 100))
    chart.add_data(helper.random_data())
    chart.download('line-simple-random.png')

def xy_random():
    chart = XYLineChart(settings.width, settings.height,
                        x_range=(0, 100), y_range=(0, 100))
    chart.add_data(helper.random_data())
    chart.add_data(helper.random_data())
    chart.download('line-xy-random.png')

def xy_rect():
    chart = XYLineChart(settings.width, settings.height,
                        x_range=(0, 100), y_range=(0, 100))
    chart.add_data([10, 90, 90, 10, 10])
    chart.add_data([10, 10, 90, 90, 10])
    chart.download('line-xy-rect.png')

def xy_circle():
    chart = XYLineChart(settings.width, settings.height,
                        x_range=(0, 100), y_range=(0, 100))
    steps = 40
    xradius = 25
    yradius = 45
    xmid = 50
    ymid = 50
    xlist = []
    ylist = []
    for angle in xrange(0, steps + 1):
        angle = float(angle) / steps * math.pi * 2
        xlist.append(math.cos(angle) * xradius + xmid)
        ylist.append(math.sin(angle) * yradius + ymid)
    chart.add_data(xlist)
    chart.add_data(ylist)
    chart.download('line-xy-circle.png')

def sparklines():
    chart = SparkLineChart(settings.width, settings.height)
    chart.add_data(helper.random_data())
    chart.download('line-sparkline.png')

def fill():

    # Set the vertical range from 0 to 50
    max_y = 50
    chart = SimpleLineChart(200, 125, y_range=[0, max_y])

    # First value is the highest Y value. Two of them are needed to be
    # plottable.
    chart.add_data([max_y] * 2)

    # 3 sets of real data
    chart.add_data([28, 30, 31, 33, 35, 36, 42, 48, 43, 37, 32, 24, 28])
    chart.add_data([16, 18, 18, 21, 23, 23, 29, 36, 31, 25, 20, 12, 17])
    chart.add_data([7, 9, 9, 12, 14, 14, 20, 27, 21, 15, 10, 3, 7])

    # Last value is the lowest in the Y axis.
    chart.add_data([0] * 2)

    # Black lines
    chart.set_colours(['000000'] * 5)

    # Filled colours
    # from the top to the first real data
    chart.add_fill_range('76A4FB', 0, 1)

    # Between the 3 data values
    chart.add_fill_range('224499', 1, 2)
    chart.add_fill_range('FF0000', 2, 3)

    # from the last real data to the
    chart.add_fill_range('80C65A', 3, 4)

    # Some axis data
    chart.set_axis_labels(Axis.LEFT, ['', max_y / 2, max_y])
    chart.set_axis_labels(Axis.BOTTOM, ['Sep', 'Oct', 'Nov', 'Dec'])

    chart.download('line-fill.png')

def stripes():
    
    # Set the vertical range from 0 to 100
    max_y = 100

    # Chart size of 200x125 pixels and specifying the range for the Y axis
    chart = SimpleLineChart(200, 125, y_range=[0, max_y])

    # Add the chart data
    data = [
        32, 34, 34, 32, 34, 34, 32, 32, 32, 34, 34, 32, 29, 29, 34, 34, 34, 37,
        37, 39, 42, 47, 50, 54, 57, 60, 60, 60, 60, 60, 60, 60, 62, 62, 60, 55,
        55, 52, 47, 44, 44, 40, 40, 37, 34, 34, 32, 32, 32, 31, 32
    ]
    chart.add_data(data)
    
    # Set the line colour to blue
    chart.set_colours(['0000FF'])

    # Set the vertical stripes
    chart.fill_linear_stripes(Chart.CHART, 0, 'CCCCCC', 0.2, 'FFFFFF', 0.2)

    # Set the horizontal dotted lines
    chart.set_grid(0, 25, 5, 5)

    # The Y axis labels contains 0 to 100 skipping every 25, but remove the
    # first number because it's obvious and gets in the way of the first X
    # label.
    left_axis = range(0, max_y + 1, 25)
    left_axis[0] = ''
    chart.set_axis_labels(Axis.LEFT, left_axis)

    # X axis labels
    chart.set_axis_labels(Axis.BOTTOM, \
        ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun'])

    chart.download('line-stripes.png')

def main():
    simple_random()
    xy_random()
    xy_rect()
    xy_circle()
    sparklines()
    fill()
    stripes()

if __name__ == '__main__':
    main()

